@@ -1,5 +1,6 @@
 
-gdina_proc_sequential_items <- function( data , q.matrix ){
+gdina_proc_sequential_items <- function( data , q.matrix )
+{
 	maxK <- max( data , na.rm=TRUE )
 	sequential <- FALSE
 	if ( maxK > 1){
@@ -7,8 +8,7 @@ gdina_proc_sequential_items <- function( data , q.matrix ){
 		data <- res0$dat.expand
 		sequential <- TRUE
 		q.matrix <- q.matrix[,-c(1:2)]
-	}
-	
+	}	
 	res <- list( data = data , sequential = sequential ,
 				q.matrix = q.matrix )
 	return(res)
